@@ -237,7 +237,15 @@ class HookDispatcher(CommandHook):
             self.logger.debug("Running hooks: %s" % hooks)
             self.command.run_kayobe_playbooks(parsed_args, hooks)
 
+    def _preflight_checks(self, parsed_args):
+        # NOTE(mgoddard): Currently all commands use KayobeAnsibleMixin, so
+        # should have a config_path attribute, but better to be defensive.
+        config_path = getattr(parsed_args, "config_path", None)
+        if config_path:
+            utils.validate_config_path(config_path)
+
     def before(self, parsed_args):
+        self._preflight_checks(parsed_args)
         self.run_hooks(parsed_args, "pre")
         return parsed_args
 
@@ -729,7 +737,7 @@ class SeedServiceDeploy(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     def take_action(self, parsed_args):
         self.app.LOG.debug("Deploying seed services")
         playbooks = _build_playbook_list(
-            "seed-deploy-containers")
+            "seed-manage-containers")
         extra_vars = {"kayobe_action": "deploy"}
         self.run_kayobe_playbooks(parsed_args, playbooks,
                                   extra_vars=extra_vars)
@@ -770,7 +778,7 @@ class SeedServiceDestroy(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
 
         extra_vars = {"kayobe_action": "destroy"}
         playbooks = _build_playbook_list(
-            "seed-deploy-containers",
+            "seed-manage-containers",
             "docker-registry")
         self.run_kayobe_playbooks(parsed_args, playbooks,
                                   extra_vars=extra_vars)
@@ -804,7 +812,7 @@ class SeedServiceUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     def take_action(self, parsed_args):
         self.app.LOG.debug("Upgrading seed services")
         playbooks = _build_playbook_list(
-            "seed-deploy-containers")
+            "seed-manage-containers")
         extra_vars = {"kayobe_action": "deploy"}
         self.run_kayobe_playbooks(parsed_args, playbooks,
                                   extra_vars=extra_vars)
@@ -1313,7 +1321,7 @@ class OvercloudDatabaseBackup(KollaAnsibleMixin, KayobeAnsibleMixin,
         extra_args = []
         if parsed_args.incremental:
             extra_args.append('--incremental')
-        self.run_kolla_ansible_overcloud(parsed_args, "mariadb_backup",
+        self.run_kolla_ansible_overcloud(parsed_args, "mariadb-backup",
                                          extra_args=extra_args)
 
 
@@ -1341,7 +1349,7 @@ class OvercloudDatabaseRecover(KollaAnsibleMixin, KayobeAnsibleMixin,
         if parsed_args.force_recovery_host:
             extra_vars['mariadb_recover_inventory_name'] = (
                 parsed_args.force_recovery_host)
-        self.run_kolla_ansible_overcloud(parsed_args, "mariadb_recovery",
+        self.run_kolla_ansible_overcloud(parsed_args, "mariadb-recovery",
                                          extra_vars=extra_vars)
 
 
@@ -1539,7 +1547,7 @@ class OvercloudServiceDeployContainers(KollaAnsibleMixin, KayobeAnsibleMixin,
             self.run_kolla_ansible_overcloud(parsed_args, "prechecks")
 
         # Perform the kolla-ansible deployment.
-        self.run_kolla_ansible_overcloud(parsed_args, "deploy-containers")
+        self.run_kolla_ansible_overcloud(parsed_args, "manage-containers")
 
         # Deploy kayobe extra services.
         playbooks = _build_playbook_list("overcloud-extras")
